@@ -3,6 +3,7 @@
 
 from typing import Optional
 
+from napari.types import PathLike, ReaderFunction
 from napari_plugin_engine import napari_hook_implementation
 
 from . import core
@@ -11,5 +12,5 @@ from . import core
 
 
 @napari_hook_implementation
-def napari_get_reader(path: core.PathLike) -> Optional[core.ReaderFunction]:
+def napari_get_reader(path: PathLike) -> Optional[ReaderFunction]:
     return core.get_reader(path, in_memory=True)
